@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.60 2004/05/24 21:50:34 xan Exp $
+ *  $Id: downloader-view.c,v 1.66 2004/07/06 14:00:51 xan Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,8 +24,6 @@
 #endif
 
 #include "downloader-view.h"
-#include "ephy-gui.h"
-#include "ephy-ellipsizing-label.h"
 #include "ephy-file-helpers.h"
 #include "ephy-embed-shell.h"
 #include "ephy-cell-renderer-progress.h"
@@ -36,7 +34,14 @@
 #include <eggtraymanager.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtkliststore.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkcellrendererpixbuf.h>
+#include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeviewcolumn.h>
+#include <gtk/gtkicontheme.h>
+#include <gtk/gtkiconfactory.h>
+#include <libgnomeui/gnome-icon-lookup.h>
 #include <glib/gi18n.h>
 
 #define CONF_DOWNLOADING_SHOW_DETAILS "/apps/epiphany/dialogs/downloader_show_details"
@@ -44,11 +49,19 @@
 enum
 {
 	COL_PERCENT,
+	COL_IMAGE,
 	COL_FILE,
 	COL_REMAINING,
 	COL_DOWNLOAD_OBJECT
 };
 
+enum
+{
+	PERCENT_COL_POS,
+	FILE_COL_POS,
+	REMAINING_COL_POS
+};
+
 #define EPHY_DOWNLOADER_VIEW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_DOWNLOADER_VIEW, DownloaderViewPrivate))
 
 struct DownloaderViewPrivate
@@ -85,11 +98,11 @@ static const
 EphyDialogProperty properties [] =
 {
 	{ "download_manager_dialog",	NULL, PT_NORMAL, 0 },
-        { "clist",			NULL, PT_NORMAL, 0 },
+	{ "clist",			NULL, PT_NORMAL, 0 },
 	{ "pause_button",		NULL, PT_NORMAL, 0 },
 	{ "abort_button",		NULL, PT_NORMAL, 0 },
 
-        { NULL }
+	{ NULL }
 };
 
 static void
@@ -117,27 +130,27 @@ downloader_view_get_type (void)
 {
        static GType downloader_view_type = 0;
 
-        if (downloader_view_type == 0)
-        {
-                static const GTypeInfo our_info =
-                {
-                        sizeof (DownloaderViewClass),
-                        NULL, /* base_init */
-                        NULL, /* base_finalize */
-                        (GClassInitFunc) downloader_view_class_init,
-                        NULL, /* class_finalize */
-                        NULL, /* class_data */
-                        sizeof (DownloaderView),
-                        0,    /* n_preallocs */
-                        (GInstanceInitFunc) downloader_view_init
-                };
+	if (downloader_view_type == 0)
+	{
+		static const GTypeInfo our_info =
+		{
+			sizeof (DownloaderViewClass),
+			NULL, /* base_init */
+			NULL, /* base_finalize */
+			(GClassInitFunc) downloader_view_class_init,
+			NULL, /* class_finalize */
+			NULL, /* class_data */
+			sizeof (DownloaderView),
+			0,    /* n_preallocs */
+			(GInstanceInitFunc) downloader_view_init
+		};
 
-                downloader_view_type = g_type_register_static (EPHY_TYPE_DIALOG,
-                                                               "DownloaderView",
-                                                               &our_info, 0);
-        }
+		downloader_view_type = g_type_register_static (EPHY_TYPE_DIALOG,
+							       "DownloaderView",
+							       &our_info, 0);
+	}
 
-        return downloader_view_type;
+	return downloader_view_type;
 }
 
 static void
@@ -145,9 +158,9 @@ downloader_view_class_init (DownloaderViewClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        parent_class = g_type_class_peek_parent (klass);
+	parent_class = g_type_class_peek_parent (klass);
 
-        object_class->finalize = downloader_view_finalize;
+	object_class->finalize = downloader_view_finalize;
 
 	g_type_class_add_private (object_class, sizeof(DownloaderViewPrivate));
 }
@@ -174,7 +187,7 @@ show_status_icon (DownloaderView *dv)
 static void
 downloader_view_init (DownloaderView *dv)
 {
-        dv->priv = EPHY_DOWNLOADER_VIEW_GET_PRIVATE (dv);
+	dv->priv = EPHY_DOWNLOADER_VIEW_GET_PRIVATE (dv);
 
 	dv->priv->downloads_hash = g_hash_table_new_full
 		(g_direct_hash, g_direct_equal, NULL,
@@ -196,7 +209,7 @@ downloader_view_finalize (GObject *object)
 	g_hash_table_destroy (dv->priv->downloads_hash);
 	g_object_unref (embed_shell);
 
-        G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 DownloaderView *
@@ -212,7 +225,7 @@ downloader_view_new (void)
 static char *
 format_interval (long interval)
 {
-	int secs, hours, mins;                                                                                                                     
+	int secs, hours, mins;														     
 	secs = (int)(interval + .5);
 	hours = secs / 3600;
 	secs -= hours * 3600;
@@ -220,11 +233,11 @@ format_interval (long interval)
 	secs -= mins * 60;
 
 	if (hours)
-        {
+	{
 		return g_strdup_printf (_("%u:%02u.%02u"), hours, mins, secs);
-        }
-        else
-        {
+	}
+	else
+	{
 		return g_strdup_printf (_("%02u.%02u"), mins, secs);
 	}
 }
@@ -435,6 +448,11 @@ downloader_view_add_download (DownloaderView *dv,
 	GtkTreeIter iter;
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
+	GtkIconTheme *theme;
+	GtkIconInfo *icon_info;
+	GdkPixbuf *pixbuf;
+	char *mime, *icon_name;
+	int width = 16, height = 16;
 
 	g_object_ref (download);
 
@@ -462,7 +480,35 @@ downloader_view_add_download (DownloaderView *dv,
 	g_signal_connect_object (download, "changed",
 				 G_CALLBACK (download_changed_cb), dv, 0);
 
+	/* Show it already */
 	ephy_dialog_show (EPHY_DIALOG (dv));
+	
+	mime =  ephy_download_get_mime (download);
+
+	theme = gtk_icon_theme_get_default ();
+	icon_name = gnome_icon_lookup (theme, NULL, NULL, NULL, NULL,
+				       mime, GNOME_ICON_LOOKUP_FLAGS_NONE, NULL);
+	g_free (mime);
+	
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height);
+	width *= 2;
+	height *= 2;
+
+	icon_info = gtk_icon_theme_lookup_icon (theme, icon_name, width, height);
+	g_free (icon_name);
+	if (icon_info == NULL) return;
+
+	icon_name = g_strdup (gtk_icon_info_get_filename (icon_info));
+	gtk_icon_info_free (icon_info);
+	
+	pixbuf = gdk_pixbuf_new_from_file_at_size (icon_name, width, height, NULL);
+	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
+			    &iter, COL_IMAGE, pixbuf, -1);
+	if (pixbuf)
+	{
+		g_object_unref (pixbuf);
+	}
+
 }
 
 static void
@@ -483,9 +529,9 @@ downloader_view_build_ui (DownloaderView *dv)
 	GtkTreeSelection *selection;
 
 	ephy_dialog_construct (d,
-                               properties,
+			       properties,
 			       ephy_file ("epiphany.glade"),
-                               "download_manager_dialog",
+			       "download_manager_dialog",
 			       NULL);
 
 	/* lookup needed widgets */
@@ -497,8 +543,9 @@ downloader_view_build_ui (DownloaderView *dv)
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview)),
 				     GTK_SELECTION_BROWSE);
 
-	liststore = gtk_list_store_new (4,
+	liststore = gtk_list_store_new (5,
 					G_TYPE_INT,
+					GDK_TYPE_PIXBUF,
 					G_TYPE_STRING,
 					G_TYPE_STRING,
 					G_TYPE_OBJECT);
@@ -508,43 +555,49 @@ downloader_view_build_ui (DownloaderView *dv)
 	g_object_unref (liststore);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(priv->treeview),
 					   TRUE);
-
-	renderer = ephy_cell_renderer_progress_new ();
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(priv->treeview),
-						     0, _("%"),
-						     renderer,
-						     "value", 0,
-						     NULL);
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview), 0);
-        gtk_tree_view_column_set_reorderable (column, TRUE);
-	gtk_tree_view_column_set_resizable (column, TRUE);
-        gtk_tree_view_column_set_sort_column_id (column, COL_PERCENT);
-
+	/* Icon and filename column*/
+	column = gtk_tree_view_column_new ();
+	gtk_tree_view_column_set_title (column, _("File"));
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	g_object_set (renderer, "xpad", 3, NULL);
+	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	gtk_tree_view_column_set_attributes (column, renderer,
+					    "pixbuf", COL_IMAGE,
+					    NULL);
 	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(priv->treeview),
-						     COL_FILE, _("File"),
-						     renderer,
-						     "text", COL_FILE,
-						     NULL);
-	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview),
-					   COL_FILE);
-        gtk_tree_view_column_set_expand (column, TRUE);
-        gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_pack_start (column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes (column, renderer,
+					     "text", COL_FILE,
+					     NULL);
+	gtk_tree_view_insert_column (GTK_TREE_VIEW (priv->treeview), column, FILE_COL_POS);
+	gtk_tree_view_column_set_expand (column, TRUE);
 	gtk_tree_view_column_set_resizable (column, TRUE);
-        gtk_tree_view_column_set_sort_column_id (column, COL_FILE);
+	gtk_tree_view_column_set_sort_column_id (column, COL_FILE);
+	gtk_tree_view_column_set_spacing (column, 3);
 
+	/* Percent column */
+	renderer = ephy_cell_renderer_progress_new ();
+	g_object_set (renderer, "xalign", 0.5, NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(priv->treeview),
+						     PERCENT_COL_POS, _("%"),
+						     renderer,
+						     "value", COL_PERCENT,
+						     NULL);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview), PERCENT_COL_POS);
+	gtk_tree_view_column_set_sort_column_id (column, COL_PERCENT);
+
+	/* Remainng time column */
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW(priv->treeview),
-						     COL_REMAINING, _("Remaining"),
+						     REMAINING_COL_POS, _("Remaining"),
 						     renderer,
 						     "text", COL_REMAINING,
 						     NULL);
+
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview),
-					   COL_REMAINING);
-        gtk_tree_view_column_set_reorderable (column, TRUE);
-	gtk_tree_view_column_set_resizable (column, TRUE);
-        gtk_tree_view_column_set_sort_column_id (column, COL_REMAINING);
+					   REMAINING_COL_POS);
+	gtk_tree_view_column_set_sort_column_id (column, COL_REMAINING);
 
 	priv->model = GTK_TREE_MODEL (liststore);
 
@@ -609,18 +662,18 @@ downloader_view_remove_download (DownloaderView *dv, EphyDownload *download)
 	gtk_tree_path_free (path);
 
 	row_ref = NULL;
-        iter2 = iter;			 
+	iter2 = iter;			 
 	if (gtk_tree_model_iter_next (GTK_TREE_MODEL (dv->priv->model), &iter))
-        {
-        	path = gtk_tree_model_get_path  (GTK_TREE_MODEL (dv->priv->model), &iter);
-        	row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (dv->priv->model), path);
-        }
-        else
-        {
-        	path = gtk_tree_model_get_path (GTK_TREE_MODEL (dv->priv->model), &iter2);
-        	if (gtk_tree_path_prev (path))
-        	{
-        		row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (dv->priv->model),
+	{
+		path = gtk_tree_model_get_path  (GTK_TREE_MODEL (dv->priv->model), &iter);
+		row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (dv->priv->model), path);
+	}
+	else
+	{
+		path = gtk_tree_model_get_path (GTK_TREE_MODEL (dv->priv->model), &iter2);
+		if (gtk_tree_path_prev (path))
+		{
+			row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (dv->priv->model),
 							      path);
 		}
 	}
@@ -641,7 +694,7 @@ downloader_view_remove_download (DownloaderView *dv, EphyDownload *download)
 		if (path != NULL)
 		{
 			gtk_tree_view_set_cursor (GTK_TREE_VIEW (dv->priv->treeview),
-					          path, NULL, FALSE);
+						  path, NULL, FALSE);
 			gtk_tree_path_free (path);
 		}
 		gtk_tree_row_reference_free (row_ref);
