@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.15 2004/05/23 01:06:34 marco Exp $
+ *  $Id: EphyBrowser.h,v 1.20 2004/06/25 11:31:22 marco Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -34,10 +34,6 @@
 #include <nsIDOMWindow.h>
 #include <nsIPrintSettings.h>
 
-#ifdef ALLOW_PRIVATE_STRINGS
-#include "nsString.h"
-#endif
-
 #ifdef ALLOW_PRIVATE_API
 #include <nsIDocShell.h>
 #include <nsIDOMEventReceiver.h>
@@ -70,6 +66,12 @@ private:
 	nsresult HandleFaviconLink (nsIDOMNode *node);
 };
 
+class EphyPopupBlockEventListener : public EphyEventListener
+{
+public:
+	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
+};
+
 class EphyBrowser
 {
 public:
@@ -82,12 +84,11 @@ public:
 	nsresult DoCommand (const char *command);
 	nsresult GetCommandState (const char *command, PRBool *enabled);
 
-	nsresult SetZoom (float aTextZoom, PRBool reflow);
+	nsresult SetZoom (float aTextZoom);
 	nsresult GetZoom (float *aTextZoom);
 
-	nsresult Print (nsIPrintSettings *options, PRBool preview);
-	nsresult GetPrintSettings (nsIPrintSettings * *options);
-	nsresult PrintPreviewClose (void);
+	nsresult Print ();
+	nsresult SetPrintPreviewMode (PRBool previewMode);
 	nsresult PrintPreviewNumPages (int *numPages);
 	nsresult PrintPreviewNavigate(PRInt16 navType, PRInt32 pageNum);
 
@@ -101,9 +102,15 @@ public:
 
 	nsresult GetSHInfo (PRInt32 *count, PRInt32 *index);
 	nsresult GetSHTitleAtIndex (PRInt32 index, PRUnichar **title);
-	nsresult GetSHUrlAtIndex (PRInt32 index, nsCString &url);
+	nsresult GetSHUrlAtIndex (PRInt32 index, nsACString &url);
 	nsresult GoToHistoryIndex (PRInt16 index);
 
+	enum { RELOAD_NORMAL = 0 };
+	enum { RELOAD_FORCE = 1 };
+	enum { RELOAD_ENCODING_CHANGE = 2 };
+
+	nsresult Reload (PRUint32 flags);
+
 	nsresult ForceEncoding (const char *encoding);
 	nsresult GetEncoding (nsACString &encoding);
 	nsresult GetForcedEncoding (nsACString &encoding);
@@ -113,8 +120,9 @@ public:
 
 	nsresult GetDocument (nsIDOMDocument **aDOMDocument);
 	nsresult GetTargetDocument (nsIDOMDocument **aDOMDocument);
-	nsresult GetDocumentUrl (nsCString &url);
-	nsresult GetTargetDocumentUrl (nsCString &url);
+	nsresult GetDocumentUrl (nsACString &url);
+	nsresult GetTargetDocumentUrl (nsACString &url);
+	nsresult GetDOMWindow (nsIDOMWindow **window);
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
@@ -125,15 +133,16 @@ private:
 	nsCOMPtr<nsIDOMEventReceiver> mEventReceiver;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
 	EphyFaviconEventListener *mFaviconEventListener;
+	EphyPopupBlockEventListener *mPopupBlockEventListener;
 	PRBool mInitialized;
 
 	nsresult GetListener (void);
 	nsresult AttachListeners (void);
 	nsresult DetachListeners (void);
-	nsresult SetZoomOnDocshell (float aZoom, nsIDocShell *DocShell);
 	nsresult GetSHistory (nsISHistory **aSHistory);
 	nsresult GetContentViewer (nsIContentViewer **aViewer);
 	nsresult GetDocumentHasModifiedForms (nsIDOMDocument *aDomDoc, PRUint32 *aNumTextFields, PRBool *aHasTextArea);
+	PRBool   CompareFormsText (nsAString &aDefaultText, nsAString &aUserText);
 };
 
 #endif
