@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.126 2003/11/17 18:51:42 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.138 2004/06/24 10:03:31 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,9 +30,17 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkactiongroup.h>
-#include <gtk/gtktoggleaction.h>
+#include <gtk/gtkcombobox.h>
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtktoggleaction.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtktreemodelsort.h>
+#include <gtk/gtkcelllayout.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkradioaction.h>
+#include <gtk/gtkclipboard.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtktreemodelsort.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
@@ -56,7 +64,7 @@
 #include "ephy-gui.h"
 #include "ephy-stock-icons.h"
 #include "ephy-search-entry.h"
-#include "ephy-toolbars-model.h"
+#include "ephy-bookmarksbar-model.h"
 #include "ephy-favicon-cache.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
@@ -141,7 +149,7 @@ struct EphyBookmarksEditorPrivate
 	GtkUIManager *ui_merge;
 	GtkActionGroup *action_group;
 	int priority_col;
-	EphyToolbarsModel *tb_model;
+	EphyBookmarksBarModel *tb_model;
 	GHashTable *props_dialogs;
 
 	GtkTreeViewColumn *title_col;
@@ -321,6 +329,15 @@ get_target_window (EphyBookmarksEditor *editor)
 	}
 }
 
+static void
+toolbar_items_changed_cb (EggToolbarsModel *model,
+			  int toolbar_position,
+			  int position,
+			  EphyBookmarksEditor *editor)
+{
+	ephy_bookmarks_editor_update_menu (editor);
+}
+
 static void
 cmd_show_in_bookmarks_bar (GtkAction *action,
 		           EphyBookmarksEditor *editor)
@@ -328,7 +345,7 @@ cmd_show_in_bookmarks_bar (GtkAction *action,
 	EphyNode *node;
 	GList *selection;
 	gboolean state, topic;
-	gulong id;
+	guint id;
 
 	if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->bm_view)))
 	{
@@ -353,13 +370,19 @@ cmd_show_in_bookmarks_bar (GtkAction *action,
 
 	if (state)
 	{
-		ephy_toolbars_model_add_bookmark
+		ephy_bookmarksbar_model_add_bookmark
 			(editor->priv->tb_model, topic, id);
 	}
 	else
 	{
-		ephy_toolbars_model_remove_bookmark
+		g_signal_handlers_block_by_func
+				(editor->priv->tb_model,
+                                 G_CALLBACK (toolbar_items_changed_cb), editor);
+		ephy_bookmarksbar_model_remove_bookmark
 			(editor->priv->tb_model, id);
+		g_signal_handlers_unblock_by_func
+				(editor->priv->tb_model,
+                                 G_CALLBACK (toolbar_items_changed_cb), editor);
 	}
 
 	g_list_free (selection);
@@ -379,13 +402,24 @@ cmd_open_bookmarks_in_tabs (GtkAction *action,
 	for (l = selection; l; l = l->next)
 	{
 		EphyNode *node = l->data;
+		EphyTab *new_tab;
 		const char *location;
 
 		location = ephy_node_get_property_string (node,
 						EPHY_NODE_BMK_PROP_LOCATION);
 
-		ephy_shell_new_tab (ephy_shell, window, NULL, location,
-			EPHY_NEW_TAB_OPEN_PAGE | EPHY_NEW_TAB_IN_EXISTING_WINDOW);
+		new_tab = ephy_shell_new_tab (ephy_shell, window, NULL, location,
+					      EPHY_NEW_TAB_OPEN_PAGE |
+					      EPHY_NEW_TAB_IN_EXISTING_WINDOW);
+		/* if there was no target window, a new one was opened. Get it
+		 * from the new tab so we open the remaining links in the
+		 * same window. See bug 138343.
+		 */
+		if (window == NULL)
+		{
+			window = EPHY_WINDOW
+				(gtk_widget_get_toplevel (GTK_WIDGET (new_tab)));
+		}
 	}
 
 	g_list_free (selection);
@@ -504,7 +538,7 @@ import_from_file_response_cb (GtkDialog *dialog, gint response,
 {
 	char *filename;
 
-	if (response == EPHY_RESPONSE_OPEN)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
@@ -543,12 +577,33 @@ import_dialog_response_cb (GtkDialog *dialog, gint response,
 		if (filename == NULL)
 		{
 			EphyFileChooser *dialog;
+			GtkFileFilter *filter;
 
 			dialog = ephy_file_chooser_new (_("Import bookmarks from file"),
 							GTK_WIDGET (editor),
 							GTK_FILE_CHOOSER_ACTION_OPEN,
-							NULL);
-			/* FIXME: set up some filters perhaps ? */
+							NULL, EPHY_FILE_FILTER_NONE);
+
+			ephy_file_chooser_add_mime_filter
+				(dialog,
+				 _("Firefox/Firebird/Mozilla bookmarks"),
+				 "application/x-mozilla-bookmarks", NULL);
+
+			ephy_file_chooser_add_mime_filter
+				(dialog, _("Galeon/Konqueror bookmarks"),
+				 "application/x-xbel", NULL);
+
+			ephy_file_chooser_add_mime_filter
+				(dialog, _("Epiphany bookmarks"),
+				 "text/rdf", NULL);
+
+			filter = ephy_file_chooser_add_pattern_filter (dialog,
+							      _("All files"),
+							      "*", NULL);
+
+			gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog),
+						     filter);
+
 			g_signal_connect (dialog, "response",
 					  G_CALLBACK (import_from_file_response_cb), editor);
 
@@ -576,6 +631,7 @@ cmd_bookmarks_import (GtkAction *action,
 	GtkCellRenderer *cell;
 	GtkListStore *store;
 	GtkTreeIter iter;
+	GtkTreeModel *sortmodel;
 
 	dialog = gtk_dialog_new_with_buttons (_("Import Bookmarks"),
 					     GTK_WINDOW (editor),
@@ -583,7 +639,7 @@ cmd_bookmarks_import (GtkAction *action,
 					     GTK_DIALOG_NO_SEPARATOR,
 					     GTK_STOCK_CANCEL,
 					     GTK_RESPONSE_CANCEL,
-					     GTK_STOCK_OK,
+					     _("I_mport"),
 					     GTK_RESPONSE_OK,
 					     NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
@@ -597,15 +653,20 @@ cmd_bookmarks_import (GtkAction *action,
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
 			    TRUE, TRUE, 0);
 
-	label = gtk_label_new (_("Choose the bookmarks source:"));
+	label = gtk_label_new (_("Import bookmarks from:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 	gtk_widget_show (label);
 
         store = GTK_LIST_STORE (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING));
-	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
-	gtk_widget_show (combo); 
+
+	sortmodel = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (store));
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sortmodel), 0, GTK_SORT_ASCENDING);
+
+	combo = gtk_combo_box_new ();
+	gtk_combo_box_set_model(GTK_COMBO_BOX (combo), sortmodel);
+	gtk_widget_show (combo);
 	g_object_set_data (G_OBJECT (dialog), "combo_box", combo);
 	g_object_unref (store);
 
@@ -615,17 +676,19 @@ cmd_bookmarks_import (GtkAction *action,
                                         "text", 0,
                                         NULL);
 
-	add_bookmarks_source (store, _("Mozilla bookmarks"),
-			      MOZILLA_BOOKMARKS_DIR, "bookmarks.html", 4);
-	add_bookmarks_source (store, _("Firebird bookmarks"),
+	add_bookmarks_source (store, _("Firebird"),
 			      FIREBIRD_BOOKMARKS_DIR, "bookmarks.html", 4);
-	add_bookmarks_source (store, _("Galeon bookmarks"),
+	add_bookmarks_source (store, _("Firefox"),
+                              FIREFOX_BOOKMARKS_DIR, "bookmarks.html", 4);
+	add_bookmarks_source (store, _("Galeon"),
 			      GALEON_BOOKMARKS_DIR, "bookmarks.xbel", 0);
-	add_bookmarks_source (store, _("Konqueror bookmarks"),
+	add_bookmarks_source (store, _("Konqueror"),
 			      KDE_BOOKMARKS_DIR, "bookmarks.xml", 0);
+	add_bookmarks_source (store, _("Mozilla"),
+			      MOZILLA_BOOKMARKS_DIR, "bookmarks.html", 4);
 
 	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter, 0, _("Import from a file"), 1, NULL, -1);
+	gtk_list_store_set (store, &iter, 0, _("File"), 1, NULL, -1);
 
 	gtk_box_pack_start (GTK_BOX (vbox), combo, TRUE, TRUE, 0);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
@@ -938,10 +1001,10 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	{
 		EphyNode *node = selected->data;
 		EphyNodePriority priority;
-		gulong id;
+		guint id;
 
 		id = ephy_node_get_id (node);
-		show_in_bookmarks_bar = ephy_toolbars_model_has_bookmark
+		show_in_bookmarks_bar = ephy_bookmarksbar_model_has_bookmark
 			(editor->priv->tb_model, id);
 
 		priority = ephy_node_get_property_int
@@ -956,12 +1019,12 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	if (bmk_focus && selected)
 	{
 		EphyNode *node = selected->data;
-		gulong id;
+		guint id;
 
 		g_return_if_fail (node != NULL);
 
 		id = ephy_node_get_id (node);
-		show_in_bookmarks_bar = ephy_toolbars_model_has_bookmark
+		show_in_bookmarks_bar = ephy_bookmarksbar_model_has_bookmark
 			(editor->priv->tb_model, id);
 
 		g_list_free (selected);
@@ -1184,10 +1247,6 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 		 G_CALLBACK (keyword_node_selected_cb),
 		 editor);
 
-	search_text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-
-	GDK_THREADS_ENTER ();
-
 	ephy_node_filter_empty (editor->priv->bookmarks_filter);
 	ephy_node_filter_add_expression (editor->priv->bookmarks_filter,
 				         ephy_node_filter_expression_new (EPHY_NODE_FILTER_EXPRESSION_STRING_PROP_CONTAINS,
@@ -1200,8 +1259,6 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 								          search_text),
 				         0);
 	ephy_node_filter_done_changing (editor->priv->bookmarks_filter);
-
-	GDK_THREADS_LEAVE ();
 }
 
 static GtkWidget *
@@ -1265,15 +1322,12 @@ node_dropped_cb (EphyNodeView *view, EphyNode *node,
 
 	for (l = nodes; l != NULL; l = l->next)
 	{
-		GnomeVFSURI *uri = l->data;
-		char *url;
+		const char *url = (const char *) l->data;
 		EphyNode *bmk;
 
-		url = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
 		bmk = ephy_bookmarks_find_bookmark (editor->priv->bookmarks, url);
-		g_free (url);
 
-		if (bmk)
+		if (bmk != NULL)
 		{
 			ephy_bookmarks_set_keyword (editor->priv->bookmarks, node, bmk);
 		}
@@ -1341,6 +1395,7 @@ get_details_value (EphyBookmarksEditor *editor)
 		value = VIEW_TITLE;
 	}
 
+	g_slist_foreach (svalues, (GFunc) g_free, NULL);
 	g_slist_free (svalues);
 
 	return value;
@@ -1620,15 +1675,6 @@ ephy_bookmarks_editor_get_property (GObject *object,
 	}
 }
 
-static void
-toolbar_items_changed_cb (EphyToolbarsModel *model,
-			  int toolbar_position,
-			  int position,
-			  EphyBookmarksEditor *editor)
-{
-	ephy_bookmarks_editor_update_menu (editor);
-}
-
 static void
 ephy_bookmarks_editor_init (EphyBookmarksEditor *editor)
 {
@@ -1636,8 +1682,9 @@ ephy_bookmarks_editor_init (EphyBookmarksEditor *editor)
 
 	editor->priv->props_dialogs = g_hash_table_new (g_direct_hash,
                                                         g_direct_equal);
-	editor->priv->tb_model = EPHY_TOOLBARS_MODEL
-		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
+	editor->priv->tb_model = EPHY_BOOKMARKSBAR_MODEL
+		(ephy_bookmarks_get_toolbars_model
+			(ephy_shell_get_bookmarks (ephy_shell)));
 
 	g_signal_connect (editor->priv->tb_model, "item_added",
 			  G_CALLBACK (toolbar_items_changed_cb), editor);
