@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.37.4.1 2004/06/14 21:26:57 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.45 2004/07/03 18:09:52 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,15 +24,18 @@
 
 #include <gtk/gtktoolitem.h>
 #include <glib/gi18n.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
 
 #include "ephy-topic-action.h"
 #include "ephy-node-common.h"
 #include "ephy-bookmarks.h"
+#include "ephy-bookmarksbar.h"
 #include "ephy-favicon-cache.h"
 #include "ephy-shell.h"
 #include "ephy-debug.h"
 #include "ephy-gui.h"
 #include "ephy-string.h"
+#include "ephy-marshal.h"
 
 static void ephy_topic_action_init       (EphyTopicAction *action);
 static void ephy_topic_action_class_init (EphyTopicActionClass *class);
@@ -41,7 +44,8 @@ static void ephy_topic_action_class_init (EphyTopicActionClass *class);
 
 struct EphyTopicActionPrivate
 {
-	int topic_id;
+	guint topic_id;
+	EphyNode *topic_node;
 };
 
 enum
@@ -52,7 +56,9 @@ enum
 
 enum
 {
-	GO_LOCATION,
+	OPEN,
+	OPEN_IN_TAB,
+	OPEN_IN_TABS,
 	LAST_SIGNAL
 };
 
@@ -140,8 +146,17 @@ menu_activate_cb (GtkWidget *item, GtkAction *action)
 	node = g_object_get_data (G_OBJECT (item), "node");
 	location = ephy_node_get_property_string
 		(node, EPHY_NODE_BMK_PROP_LOCATION);
-	g_signal_emit (action, ephy_topic_action_signals[GO_LOCATION],
-		       0, location);
+
+	if (ephy_gui_is_middle_click ())
+	{
+		g_signal_emit (action, ephy_topic_action_signals[OPEN_IN_TAB],
+			       0, location, FALSE);
+	}
+	else
+	{
+		g_signal_emit (action, ephy_topic_action_signals[OPEN],
+			       0, location);
+	}
 }
 
 static void
@@ -215,6 +230,16 @@ sort_bookmarks (gconstpointer a, gconstpointer b)
 
 #define MAX_LENGTH 32
 
+static gboolean
+can_open_in_tabs (EphyTopicAction *action)
+{
+	GPtrArray *children;
+
+	children = ephy_node_get_children (action->priv->topic_node);
+
+	return (children->len > 1);
+}
+
 static void
 append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node, gboolean show_empty)
 {
@@ -234,6 +259,8 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 		gtk_widget_set_sensitive (item, FALSE);
 		gtk_widget_show (item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+		return;
 	}
 	else
 	{
@@ -295,6 +322,68 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 	}
 }
 
+static void
+open_in_tabs_activate_cb (GtkWidget *menu, EphyTopicAction *action)
+{
+	GList *uri_list = NULL;
+	GPtrArray *children;
+	int i;
+
+	children = ephy_node_get_children (action->priv->topic_node);
+	for (i = 0; i < children->len; i++)
+	{
+		const char *address;
+		EphyNode *child;
+
+		child = g_ptr_array_index (children, i);
+		address = ephy_node_get_property_string
+			(child, EPHY_NODE_BMK_PROP_LOCATION);
+		uri_list = g_list_append (uri_list, g_strdup (address));
+	}
+
+	g_signal_emit (action, ephy_topic_action_signals[OPEN_IN_TABS],
+		       0, uri_list);
+	g_list_foreach (uri_list, (GFunc)g_free, NULL);
+	g_list_free (uri_list);
+}
+
+static void
+remove_activate_cb (GtkWidget *menu, GtkWidget *proxy)
+{
+	EphyBookmarks *bookmarks;
+	EggToolbarsModel *model;
+	GtkWidget *item, *toolbar;
+	int pos;
+
+	item = gtk_widget_get_ancestor (proxy, GTK_TYPE_TOOL_ITEM);
+	g_return_if_fail (item != NULL);
+
+	toolbar = gtk_widget_get_ancestor (proxy, GTK_TYPE_TOOLBAR);
+	g_return_if_fail (toolbar != NULL);
+
+	pos = gtk_toolbar_get_item_index (GTK_TOOLBAR (toolbar),
+				          GTK_TOOL_ITEM (item));
+
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+	model = ephy_bookmarks_get_toolbars_model (bookmarks);
+	egg_toolbars_model_remove_item (model, 0, pos);
+}
+
+static GtkWidget *
+add_open_in_tabs_menu (EphyTopicAction *action, GtkWidget *menu)
+{
+	GtkWidget *item;
+
+	item = gtk_menu_item_new_with_mnemonic (_("_Open in Tabs"));
+	gtk_widget_show (item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+	g_signal_connect (item, "activate",
+			  G_CALLBACK (open_in_tabs_activate_cb), action);
+
+	return item;
+}
+
 static GtkWidget *
 build_bookmarks_menu (EphyTopicAction *action, EphyNode *node)
 {
@@ -304,6 +393,17 @@ build_bookmarks_menu (EphyTopicAction *action, EphyNode *node)
 
 	append_bookmarks_menu (action, menu, node, TRUE);
 
+	if (can_open_in_tabs (action))
+	{
+		GtkWidget *item;
+
+		item = gtk_separator_menu_item_new ();
+		gtk_widget_show (item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+		add_open_in_tabs_menu (action, menu);
+	}
+
 	return menu;
 }
 
@@ -341,18 +441,19 @@ sort_topics (gconstpointer a, gconstpointer b)
 }
 
 static GtkWidget *
-build_topics_menu (EphyTopicAction *action, EphyNode *node)
+build_topics_menu (EphyTopicAction *action)
 {
 	GtkWidget *menu, *item;
 	GPtrArray *children;
 	int i;
 	EphyBookmarks *bookmarks;
-	EphyNode *all, *uncategorized;
+	EphyNode *all, *uncategorized, *node;
 	EphyNodePriority priority;
 	GList *node_list = NULL, *l = NULL;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 	all = ephy_bookmarks_get_bookmarks (bookmarks);
+	node = ephy_bookmarks_get_keywords (bookmarks);
 
 	menu = gtk_menu_new ();
 
@@ -406,22 +507,13 @@ build_topics_menu (EphyTopicAction *action, EphyNode *node)
 static GtkWidget *
 build_menu (EphyTopicAction *action)
 {
-	EphyNode *node;
-	EphyBookmarks *bookmarks;
-
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-
 	if (action->priv->topic_id == BOOKMARKS_NODE_ID)
 	{
-		LOG ("Build all bookmarks crap menu")
-
-		node = ephy_bookmarks_get_keywords (bookmarks);
-		return build_topics_menu (action, node);
+		return build_topics_menu (action);
 	}
 	else
 	{
-		node = ephy_bookmarks_get_from_id (bookmarks, action->priv->topic_id);
-		return build_bookmarks_menu (action, node);
+		return build_bookmarks_menu (action, action->priv->topic_node);
 	}
 }
 
@@ -478,6 +570,56 @@ create_menu_item (GtkAction *action)
 	return menu_item;
 }
 
+static void
+show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
+		   GtkMenuPositionFunc func)
+{
+	GtkWidget *menu, *item;
+
+	menu = gtk_menu_new ();
+
+	item = add_open_in_tabs_menu (action, menu);
+	gtk_widget_set_sensitive (item, can_open_in_tabs (action));
+
+	item = gtk_separator_menu_item_new ();
+	gtk_widget_show (item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+	item = gtk_image_menu_item_new_from_stock (GTK_STOCK_REMOVE, NULL);
+	gtk_widget_show (item);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (item, "activate",
+			  G_CALLBACK (remove_activate_cb), proxy);
+
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy, 3,
+			gtk_get_current_event_time ());
+}
+
+static void
+popup_menu_cb (GtkWidget *widget, EphyTopicAction *action)
+{
+	if (gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))
+        {
+                show_context_menu (action, widget,
+				   ephy_gui_menu_position_under_widget);
+        }
+}
+
+static gboolean
+button_press_cb (GtkWidget *widget,
+		 GdkEventButton *event,
+		 EphyTopicAction *action)
+{
+	if (event->button == 3 &&
+	    gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))	
+	{
+		show_context_menu (action, widget, NULL);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
@@ -496,27 +638,42 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "toggled",
 				  G_CALLBACK (button_toggled_cb), action);
-
-		/* We want the menu to popup up on mouse down */
+		g_signal_connect (button, "popup_menu",
+				  G_CALLBACK (popup_menu_cb), action);
+		g_signal_connect (button, "button-press-event",
+				  G_CALLBACK (button_press_cb), action);
 		g_signal_connect (button, "pressed",
 				  G_CALLBACK (button_pressed_cb), action);
 	}
 }
 
+static void
+ephy_topic_action_set_topic_id (EphyTopicAction *action, guint id)
+{
+	EphyBookmarks *bookmarks;
+	EphyNode *node;
+
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+	node = ephy_bookmarks_get_from_id (bookmarks, id);
+
+	action->priv->topic_node = node;
+	action->priv->topic_id = id;
+}
+
 static void
 ephy_topic_action_set_property (GObject *object,
                                 guint prop_id,
                                 const GValue *value,
                                 GParamSpec *pspec)
 {
-	EphyTopicAction *bmk;
+	EphyTopicAction *topic;
 
-	bmk = EPHY_TOPIC_ACTION (object);
+	topic = EPHY_TOPIC_ACTION (object);
 
 	switch (prop_id)
 	{
 		case PROP_TOPIC_ID:
-			bmk->priv->topic_id = g_value_get_int (value);
+			ephy_topic_action_set_topic_id (topic, g_value_get_int (value));
 			break;
 	}
 }
@@ -555,17 +712,40 @@ ephy_topic_action_class_init (EphyTopicActionClass *class)
 	object_class->set_property = ephy_topic_action_set_property;
 	object_class->get_property = ephy_topic_action_get_property;
 
-	ephy_topic_action_signals[GO_LOCATION] =
-                g_signal_new ("go_location",
+	ephy_topic_action_signals[OPEN] =
+                g_signal_new ("open",
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (EphyTopicActionClass, go_location),
+                              G_STRUCT_OFFSET (EphyTopicActionClass, open),
                               NULL, NULL,
                               g_cclosure_marshal_VOID__STRING,
                               G_TYPE_NONE,
                               1,
 			      G_TYPE_STRING);
 
+	ephy_topic_action_signals[OPEN_IN_TAB] =
+                g_signal_new ("open_in_tab",
+                              G_OBJECT_CLASS_TYPE (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (EphyTopicActionClass, open_in_tab),
+                              NULL, NULL,
+                              ephy_marshal_VOID__STRING_BOOLEAN,
+                              G_TYPE_NONE,
+                              2,
+			      G_TYPE_STRING,
+			      G_TYPE_BOOLEAN);
+
+	ephy_topic_action_signals[OPEN_IN_TABS] =
+                g_signal_new ("open_in_tabs",
+                              G_OBJECT_CLASS_TYPE (object_class),
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (EphyTopicActionClass, open_in_tabs),
+                              NULL, NULL,
+                              g_cclosure_marshal_VOID__POINTER,
+                              G_TYPE_NONE,
+                              1,
+			      G_TYPE_POINTER);
+
 	g_object_class_install_property (object_class,
                                          PROP_TOPIC_ID,
                                          g_param_spec_int ("topic_id",
@@ -612,7 +792,7 @@ topic_child_changed_cb (EphyNode *node,
 			guint property_id,
 			GtkAction *action)
 {
-	gulong id;
+	guint id;
 
 	id = EPHY_TOPIC_ACTION (action)->priv->topic_id;
 
