@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.115.4.8 2004/08/04 13:53:14 chpe Exp $
+ *  $Id: window-commands.c,v 1.128 2004/06/26 18:28:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,7 +44,7 @@
 #include "ephy-state.h"
 #include "ephy-gui.h"
 #include "ephy-zoom.h"
-#include "ephy-toolbars-model.h"
+#include "egg-toolbars-model.h"
 #include "egg-editable-toolbar.h"
 #include "egg-toolbar-editor.h"
 
@@ -55,6 +55,8 @@
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <gtk/gtkeditable.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkicontheme.h>
 #include <gtk/gtktoggleaction.h>
 #include <libgnomeui/gnome-about.h>
 #include <glib/gi18n.h>
@@ -75,10 +77,12 @@ void
 window_cmd_file_print_setup (GtkAction *action,
 			     EphyWindow *window)
 {
-	EphyEmbedSingle *single;
+	EphyDialog *dialog;
 
-	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
-	ephy_embed_single_print_setup (single);
+	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
+
+	ephy_dialog_show (dialog);
 }
 
 void
@@ -270,8 +274,7 @@ window_cmd_view_reload (GtkAction *action,
 
 	ephy_embed_activate (embed);
 
-	ephy_embed_reload (embed, force ? EMBED_RELOAD_FORCE
-					: EMBED_RELOAD_NORMAL);
+	ephy_embed_reload (embed, force);
 }
 
 void
@@ -394,7 +397,8 @@ window_cmd_file_open (GtkAction *action,
 	dialog = ephy_file_chooser_new (_("Open"),
 					GTK_WIDGET (window),
 					GTK_FILE_CHOOSER_ACTION_OPEN,
-					CONF_STATE_OPEN_DIR);
+					CONF_STATE_OPEN_DIR,
+					EPHY_FILE_FILTER_ALL_SUPPORTED);
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (open_response_cb), window);
@@ -428,6 +432,19 @@ window_cmd_file_save_as (GtkAction *action,
 	g_object_unref (G_OBJECT(persist));
 }
 
+
+void
+window_cmd_file_work_offline (GtkAction *action,
+		              EphyWindow *window)
+{
+	EphyEmbedSingle *single;
+	gboolean offline;
+
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	offline = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+	ephy_embed_single_set_offline_mode (single, offline);
+}
+
 void
 window_cmd_file_close_window (GtkAction *action,
 		              EphyWindow *window)
@@ -589,6 +606,9 @@ void
 window_cmd_view_fullscreen (GtkAction *action,
 			    EphyWindow *window)
 {
+	/* Otherwise the other toolbar layout shows briefly while switching */
+	gtk_widget_hide (ephy_window_get_toolbar (window));
+
 	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
 	{
 		gtk_window_fullscreen (GTK_WINDOW (window));
@@ -702,11 +722,6 @@ editor_can_open_uri (char *address)
 		gnome_vfs_uri_unref (uri);
 	}
 
-	if (app)
-	{
-		gnome_vfs_mime_application_free (app);
-	}
-
 	return result;
 }
 
@@ -768,8 +783,6 @@ window_cmd_view_page_source (GtkAction *action,
 	{
 		save_temp_source (embed);
 	}
-
-	g_free (address);
 }
 
 void
@@ -810,30 +823,26 @@ window_cmd_edit_prefs (GtkAction *action,
 
 static void
 toolbar_editor_destroy_cb (GtkWidget *tbe,
-			   Toolbar *t)
+			   EphyWindow *window)
 {
-	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR (t), FALSE);
+	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR
+		(ephy_window_get_toolbar (window)), FALSE);
+	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR
+		(ephy_window_get_bookmarksbar (window)), FALSE);
 }
 
 static void
 toolbar_editor_response_cb (GtkDialog  *dialog,
 			    gint response_id,
-			    gpointer data)
+			    EggToolbarsModel *model)
 {
-	EphyToolbarsModel *model;
-	int n;
-
 	switch (response_id)
 	{
 	case GTK_RESPONSE_CLOSE:
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	case RESPONSE_ADD_TOOLBAR:
-		model = EPHY_TOOLBARS_MODEL
-			(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
-		n = egg_toolbars_model_n_toolbars (EGG_TOOLBARS_MODEL (model));
-		egg_toolbars_model_add_toolbar (EGG_TOOLBARS_MODEL (model),
-						n - 1, "UserCreated");
+		egg_toolbars_model_add_toolbar (model, -1, "UserCreated");
 		break;
 	case GTK_RESPONSE_HELP:
 		ephy_gui_help (GTK_WINDOW (dialog), "epiphany", "to-edit-toolbars");
@@ -846,31 +855,28 @@ window_cmd_edit_toolbar (GtkAction *action,
 			 EphyWindow *window)
 {
 	GtkWidget *editor;
-	EphyToolbarsModel *model;
+	EggToolbarsModel *model;
 	GtkWidget *t;
 	GtkWidget *dialog;
 
-	model = EPHY_TOOLBARS_MODEL
+	model = EGG_TOOLBARS_MODEL
 		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 	t = ephy_window_get_toolbar (window);
 
 	dialog = gtk_dialog_new ();
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Toolbar Editor"));
-        gtk_window_set_transient_for (GTK_WINDOW (dialog),
-				      GTK_WINDOW (window));
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
-	editor = egg_toolbar_editor_new
-		(GTK_UI_MANAGER (window->ui_merge),
-		 EGG_TOOLBARS_MODEL (model));
+	editor = egg_toolbar_editor_new (GTK_UI_MANAGER (window->ui_merge), model);
 	egg_toolbar_editor_load_actions (EGG_TOOLBAR_EDITOR (editor),
 					 ephy_file ("epiphany-toolbar.xml"));
 	gtk_container_set_border_width (GTK_CONTAINER (EGG_TOOLBAR_EDITOR (editor)), 5);
 	gtk_box_set_spacing (GTK_BOX (EGG_TOOLBAR_EDITOR (editor)), 5);
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), editor);
 	g_signal_connect (editor, "destroy",
-			  G_CALLBACK (toolbar_editor_destroy_cb),
-			  t);
+			  G_CALLBACK (toolbar_editor_destroy_cb), window);
 	gtk_widget_show (editor);
 	
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
@@ -885,7 +891,7 @@ window_cmd_edit_toolbar (GtkAction *action,
 			       GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	
 	g_signal_connect (G_OBJECT (dialog), "response",
-			  G_CALLBACK (toolbar_editor_response_cb), NULL);
+			  G_CALLBACK (toolbar_editor_response_cb), model);
 	ephy_state_add_window (dialog,
 			       "toolbar_editor",
 		               500, 330,
@@ -893,6 +899,8 @@ window_cmd_edit_toolbar (GtkAction *action,
 	gtk_widget_show (dialog);
 
 	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR (t), TRUE);
+	egg_editable_toolbar_set_edit_mode
+		(EGG_EDITABLE_TOOLBAR (ephy_window_get_bookmarksbar (window)), TRUE);
 }
 
 void
@@ -909,7 +917,7 @@ window_cmd_help_about (GtkAction *action,
 	static GtkWidget *about = NULL;
 	GtkWidget** ptr;
 	const char *icon_path;
-	GdkPixbuf *logo = NULL;
+	GdkPixbuf *icon = NULL;
 	GtkIconTheme *icon_theme;
 	GtkIconInfo *icon_info;
 
@@ -924,7 +932,7 @@ window_cmd_help_about (GtkAction *action,
 	char *documenters[] = {
 		"Patanjali Somayaji <patanjali@codito.com>",
 		"David Bordoley <bordoley@msu.edu>",
-		"Piers Cornwell", 
+		"Piers Cornwell <piers@gnome.org>", 
 		NULL
 	};
 
@@ -948,7 +956,7 @@ window_cmd_help_about (GtkAction *action,
 
 		if (icon_path != NULL)
 		{
-			logo = gdk_pixbuf_new_from_file (icon_path, NULL);
+			icon = gdk_pixbuf_new_from_file (icon_path, NULL);
 		}
 	}
 	else
@@ -963,13 +971,13 @@ window_cmd_help_about (GtkAction *action,
 		       (const char **)authors,
 		       (const char **)documenters,
 		       strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-		       logo);
+		       icon);
 
-	gtk_window_set_icon (GTK_WINDOW (about), logo);
+	gtk_window_set_icon (GTK_WINDOW (about), icon);
 
-	if (logo != NULL)
+	if (icon != NULL)
 	{
-		g_object_unref (logo);
+		g_object_unref (icon);
 	}
 
 	gtk_window_set_transient_for (GTK_WINDOW (about),
